@@ -5,6 +5,7 @@
 # X.org server. XRandR allows to configure resolution, refresh rate, rotation
 # of the screen and multiple outputs of graphics cards.
 #
+# Copyright 2014 © Canonical Ltd.
 # Copyright 2007 © Sebastian Heinlein <sebastian.heinlein@web.de>
 # Copyright 2007 © Michael Vogt <mvo@ubuntu.com>
 # Copyright 2007 © Canonical Ltd.
@@ -35,6 +36,11 @@
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 # MA  02110-1301  USA
 
+from __future__ import absolute_import
+from __future__ import division
+from __future__ import print_function
+from __future__ import unicode_literals
+
 from ctypes import (
     POINTER,
     Structure,
@@ -212,7 +218,7 @@ def _array_conv(array, type, conv=lambda x: x):
     return res
 
 
-class Output:
+class Output(object):
     """The output is a reference to a supported output jacket of the graphics
        card. Outputs are attached to a hardware pipe to be used. Furthermore
        they can be a clone of another output or show a subset of the screen"""
@@ -335,7 +341,7 @@ class Output:
     def set_to_preferred_mode(self):
         modes = self.get_available_modes()
         mode = modes[self.get_preferred_mode()]
-        if mode != None:
+        if mode is not None:
             self._mode = mode.id
             return
         raise RRError("Preferred mode is not available")
@@ -372,7 +378,7 @@ class Output:
             return self._changes != CHANGES_NONE
 
 
-class Crtc:
+class Crtc(object):
     """The crtc is a reference to a hardware pipe that is provided by the
        graphics device. Outputs can be attached to crtcs"""
 
@@ -386,7 +392,7 @@ class Crtc:
     def __del__(self):
         """Frees the reference to the rendering pipe if the instance gets
            removed"""
-        rr.XRRFreeCrtcConfigInfo(self._info)
+        rr.XRRFreeCrtcInfo(self._info)
 
     def get_xid(self):
         """Returns the internal id of the crtc from the X server"""
@@ -515,7 +521,7 @@ class Crtc:
         return False
 
 
-class Screen:
+class Screen(object):
     def __init__(self, dpy, screen=-1):
         """Initializes the screen"""
         # Some sane default values
@@ -711,7 +717,7 @@ class Screen:
             self._size_index = index
         else:
             raise RRError("There isn't any size associated "
-                          "to the index %s" % index)
+                          "to the index {}".format(index))
 
     def set_rotation(self, rotation):
         """Sets the rotation of the screen. To get in effect call
@@ -727,8 +733,8 @@ class Screen:
         if rate in self.get_available_rates_for_size_index(self._size_index):
             self._rate = rate
         else:
-            raise RRError("The chosen refresh rate %s is not "
-                          "supported" % rate)
+            raise RRError(
+                "The chosen refresh rate {0} is not supported".format(rate))
 
     def get_mode_by_xid(self, xid):
         """Returns the mode of the given xid"""
@@ -755,24 +761,24 @@ class Screen:
     def print_info(self, verbose=False):
         """Prints some information about the detected screen and its outputs"""
         _check_required_version((1, 0))
-        print("Screen %s: minimum %s x %s, current %s x %s, maximum %s x %s" %\
-              (self._screen,
-               self._width_min, self._height_min,
-               self._width, self._height,
-               self._width_max, self._height_max))
-        print("          %smm x %smm" % (self._width_mm, self._height_mm))
-        print("Crtcs: %s" % len(self.crtcs))
+        print((
+            "Screen {0}: minimum {1} x {2}, current {3} x {4},"
+            " maximum {5} x {6}"
+        ).format(self._screen, self._width_min, self._height_min, self._width,
+                 self._height, self._width_max, self._height_max))
+        print("          {0}mm x {0}mm".format(self._width_mm,
+                                               self._height_mm))
+        print("Crtcs: {0}".format(len(self.crtcs)))
         if verbose:
-            print("Modes (%s):" % self._resources.contents.nmode)
+            print("Modes ({0}):".format(self._resources.contents.nmode))
             modes = self._resources.contents.modes
             for i in range(self._resources.contents.nmode):
-                print("  %s - %sx%s" % (modes[i].name,
-                                       modes[i].width,
-                                       modes[i].height))
+                print("  {0} - {1}x{2}".format(
+                    modes[i].name, modes[i].width, modes[i].height))
         i = 0
         print("Sizes @ Refresh Rates:")
         for s in self.get_available_sizes():
-            print("  [%s] %s x %s @ %s" % (
+            print("  [{0}] {1} x {2} @ {3}".format(
                 i, s.width, s.height,
                 self.get_available_rates_for_size_index(i)))
             i += 1
@@ -889,7 +895,7 @@ class Screen:
         for output in self.get_outputs():
             # Skip not changed and not used outputs
             if not output.has_changed(CHANGES_RELATION) or \
-               output._mode == None:
+               output._mode is None:
                 continue
             relative = output._relative_to
             mode = self.get_mode_by_xid(output._mode)
@@ -900,8 +906,8 @@ class Screen:
                 output._changes = output._changes | CHANGES_POSITION
             if output._relation == RELATION_LEFT_OF:
                 output._y = relative._y + output._relation_offset
-                output._x = relative._x - \
-                            get_mode_width(mode, output._rotation)
+                output._x = relative._x - get_mode_width(
+                    mode, output._rotation)
             elif output._relation == RELATION_RIGHT_OF:
                 output._y = relative._y + output._relation_offset
                 output._x = relative._x + get_mode_width(mode_relative,
@@ -923,14 +929,14 @@ class Screen:
         min_x = 32768
         min_y = 32768
         for output in self.get_outputs():
-            if output._mode == None:
+            if output._mode is None:
                 continue
             if output._x < min_x:
                 min_x = output._x
             if output._y < min_y:
                 min_y = output._y
         for output in self.get_outputs():
-            if output._mode == None:
+            if output._mode is None:
                 continue
             output._x -= min_x
             output._y -= min_y
@@ -1035,7 +1041,7 @@ def _from_gamma(g):
 def _check_required_version(version):
     """Raises an exception if the given or a later version of xrandr is not
        available"""
-    if XRANDR_VERSION == None or XRANDR_VERSION < version:
+    if XRANDR_VERSION is None or XRANDR_VERSION < version:
         raise UnsupportedRRError(version, XRANDR_VERSION)
 
 
