@@ -15,7 +15,12 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with Checkbox.  If not, see <http://www.gnu.org/licenses/>.
-#
+
+from __future__ import absolute_import
+from __future__ import division
+from __future__ import print_function
+from __future__ import unicode_literals
+
 from struct import calcsize
 
 
@@ -24,18 +29,18 @@ def get_bitmask(key):
     for value in reversed(key.split()):
         value = int(value, 16)
         bitmask.append(value)
-
     return bitmask
 
+
 def get_bitcount(bitmask):
     bitcount = 0
     for value in bitmask:
         while value:
             bitcount += 1
             value &= (value - 1)
-
     return bitcount
 
+
 def test_bit(bit, bitmask, bits=None):
     if bits is None:
         bits = calcsize("l") * 8
