@@ -15,11 +15,16 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with Checkbox.  If not, see <http://www.gnu.org/licenses/>.
-#
+
+from __future__ import absolute_import
+from __future__ import division
+from __future__ import print_function
+from __future__ import unicode_literals
+
 import re
 
 
-class MeminfoParser:
+class MeminfoParser(object):
     """Parser for the /proc/meminfo file."""
 
     def __init__(self, stream):
