@@ -351,14 +351,21 @@ AttributeName = p.Regex("[a-zA-Z][^:\n]+").setResultsName("attribute-name")
 VolumeAttributeValue = (
     p.Combine(
         p.Or([
-            p.Literal("(invalid)"),
-            p.Regex("([0-9]+: +[0-9]+% ?)+")
-        ])
-        + p.LineEnd()
-        + p.Optional(p.White('\t').suppress())
-        + p.Or([
-            p.Literal("(invalid)"),
-            p.Regex("([0-9]+: -?[0-9]+\.[0-9]+ dB ?)+")
+            p.Or([
+                p.Literal("(invalid)"),
+                p.Regex("([0-9]+: +[0-9]+% ?)+")
+            ])
+            + p.LineEnd()
+            + p.Optional(p.White('\t').suppress())
+            + p.Or([
+                p.Literal("(invalid)"),
+                p.Regex("([0-9]+: -?([0-9]+\.[0-9]+|inf) dB ?)+"),
+            ]),
+            p.Or([
+                p.Literal("(invalid)"),
+                p.Regex("([\w\-]+: [0-9]+ / +[0-9]+% /"
+                        " +-?([0-9]+\.[0-9]+|inf) dB,? *)+")
+            ])
         ])
         + p.LineEnd()
         + p.Optional(p.White('\t').suppress())
