@@ -94,6 +94,10 @@ class SubmissionRun(object):
         self.result.setdefault("package_versions", [])
         self.result["package_versions"].append(package_version)
 
+    def addSnapPackageVersion(self, **snap_package_version):
+        self.result.setdefault("snap_package_versions", [])
+        self.result["snap_package_versions"].append(snap_package_version)
+
     def addTestResult(self, **test_result):
         self.result.setdefault("test_results", [])
         self.result["test_results"].append(test_result)
@@ -330,6 +334,18 @@ class TestSubmissionParser(TestCase):
         self.assertEqual(package_version["name"], "accountsservice")
         self.assertEqual(package_version["version"], "0.6.21-6ubuntu2")
 
+    def test_snap_package_versions(self):
+        """Snap Package versions are in the snap_packages element."""
+        result = self.getResult("submission_snap_packages.xml")
+        self.assertTrue("snap_package_versions" in result)
+        self.assertEqual(len(result["snap_package_versions"]), 1)
+
+        package_version = result["snap_package_versions"][0]
+        self.assertEqual(package_version["name"], "ubuntu-core")
+        self.assertEqual(package_version["version"], "14")
+        self.assertEqual(package_version["date"], "2015-10-13")
+        self.assertEqual(package_version["developer"], "ubuntu")
+
     def test_package_modaliases(self):
         """
         Modaliases information is in the packages element if a package
